@@ -139,7 +139,7 @@ namespace Banshee
 			BorderWidth = 12;
 			SetSizeRequest(400, -1);
 			Resizable = false;
-			Icon =  Gdk.Pixbuf.LoadFromResource("sonance-icon.png");
+			Icon =  Gdk.Pixbuf.LoadFromResource("banshee-icon.png");
 			
 			vboxWindow = new VBox();
 			vboxWindow.Spacing = 12;
@@ -224,7 +224,7 @@ namespace Banshee
 				"Are you sure you want to cancel the CD Burn?");
 				
 			dialog.Title = "Cancel CD Burn?";
-			dialog.Icon =  Gdk.Pixbuf.LoadFromResource("sonance-icon.png");
+			dialog.Icon =  Gdk.Pixbuf.LoadFromResource("banshee-icon.png");
 			dialog.DefaultResponse = ResponseType.No;
 			response = (ResponseType)dialog.Run();
 			dialog.Destroy();
@@ -366,7 +366,7 @@ namespace Banshee
 						"are needed on the media.", -remaining / 60));
 
 				dialog.Title = "Not Enough Space";
-				dialog.Icon =  Gdk.Pixbuf.LoadFromResource("sonance-icon.png");
+				dialog.Icon =  Gdk.Pixbuf.LoadFromResource("banshee-icon.png");
 				dialog.DefaultResponse = ResponseType.Ok;
 				dialog.Run();
 				dialog.Destroy();
@@ -404,7 +404,7 @@ namespace Banshee
 				
 				drive = BurnUtil.GetDriveByIdOrDefault(selectedBurnerId);
 					
-				if(drive.Equals(BurnDrive.Zero))
+				if(drive == null)
 					throw new ApplicationException("No CD Burners Available");
 					
 				selectedBurnerId = BurnUtil.GetDriveUniqueId(drive);
@@ -439,11 +439,13 @@ namespace Banshee
 					recorder.WriteTracks(drive,
 					tracks.ToArray(typeof(BurnRecorderTrack)) 
 						as BurnRecorderTrack [],
-					drive.MaxSpeedWrite, flags);
+					drive.MaxWriteSpeed, flags);
 				
 				if(result == BurnRecorderResult.Error) {
-					string header = recorder.ErrorMessage;
-					string message = recorder.ErrorMessageDetails;
+					//string header = recorder.ErrorMessage;
+					//string message = recorder.ErrorMessageDetails;
+					string header = null;
+					string message = null;
 					if(header == null || header.Equals(String.Empty))
 						header = "Error Burning CD";
 					if(message == null || message.Equals(String.Empty))
@@ -478,7 +480,7 @@ namespace Banshee
 				"Would you like to continue?");
 				
 			dialog.Title = "Data Loss Warning";
-			dialog.Icon =  Gdk.Pixbuf.LoadFromResource("sonance-icon.png");
+			dialog.Icon =  Gdk.Pixbuf.LoadFromResource("banshee-icon.png");
 			dialog.DefaultResponse = ResponseType.Ok;
 			response = (ResponseType)dialog.Run();
 			
@@ -543,7 +545,7 @@ namespace Banshee
 					"Please insert a blank CD disk for the burn process.");
 				
 				dialog.Title = "Insert Blank CD";
-				dialog.Icon =  Gdk.Pixbuf.LoadFromResource("sonance-icon.png");
+				dialog.Icon =  Gdk.Pixbuf.LoadFromResource("banshee-icon.png");
 				dialog.DefaultResponse = ResponseType.Ok;
 				response = (ResponseType)dialog.Run();
 				dialog.Destroy();
@@ -577,7 +579,7 @@ namespace Banshee
 				message);
 
 			dialog.Title = "Error Burning Disk";
-			dialog.Icon =  Gdk.Pixbuf.LoadFromResource("sonance-icon.png");
+			dialog.Icon =  Gdk.Pixbuf.LoadFromResource("banshee-icon.png");
 			dialog.DefaultResponse = ResponseType.Ok;
 			dialog.Run();
 			dialog.Destroy();
@@ -602,7 +604,7 @@ namespace Banshee
 				"The selected audio was successfully written to the CD.");
 
 			dialog.Title = "CD Burning Complete";
-			dialog.Icon =  Gdk.Pixbuf.LoadFromResource("sonance-icon.png");
+			dialog.Icon =  Gdk.Pixbuf.LoadFromResource("banshee-icon.png");
 			dialog.DefaultResponse = ResponseType.Ok;
 			dialog.Run();
 			dialog.Destroy();
