@@ -189,7 +189,10 @@ namespace Banshee
 			ImagePrevious.SetFromStock("media-prev", IconSize.LargeToolbar);
 			ImageNext.SetFromStock("media-next", IconSize.LargeToolbar);
 			ImagePlayPause.SetFromStock("media-play", IconSize.LargeToolbar);
+			
 			ImageBurn.SetFromStock("media-burn", IconSize.LargeToolbar);
+			
+			gxml["ButtonBurn"].Visible = Environment.GetEnvironmentVariable("BANSHEE_BURN_ENABLE") != null;
 				
 			((Gtk.Image)gxml["ImageShuffle"]).Pixbuf = 
 				Gdk.Pixbuf.LoadFromResource("media-shuffle.png");
@@ -252,6 +255,7 @@ namespace Banshee
 			playlistModel.Updated += OnPlaylistUpdated;
 			playlistView.ButtonPressEvent += OnPlaylistViewButtonPressEvent;
 			playlistView.MotionNotifyEvent += OnPlaylistViewMotionNotifyEvent;
+			playlistView.ButtonReleaseEvent += OnPlaylistViewButtonReleaseEvent;
 			playlistView.DragDataReceived += OnPlaylistViewDragDataReceived;
 			playlistView.DragDataGet += OnPlaylistViewDragDataGet;
 			playlistView.DragMotion += OnPlaylistViewDragMotion;
@@ -275,6 +279,11 @@ namespace Banshee
 			ipodDiskUsageBar = new ProgressBar();
 			box.PackStart(ipodDiskUsageBar, false, false, 0);
 			
+			Button ipodSyncButton = new Button(
+				new Gtk.Image("gtk-copy", IconSize.Menu));
+			ipodSyncButton.Clicked += OnIpodSyncClicked;
+			box.PackStart(ipodSyncButton, false, false, 0);
+			
 			Button ipodPropertiesButton = new Button(
 				new Gtk.Image("gtk-properties", IconSize.Menu));
 			ipodPropertiesButton.Clicked += OnIpodPropertiesClicked;
@@ -323,11 +332,14 @@ namespace Banshee
 			SetTip(gxml["ScaleTime"], Catalog.GetString("Current Position in Song"));
 			SetTip(volumeButton, Catalog.GetString("Adjust Volume"));
 			SetTip(ipodDiskUsageBar, Catalog.GetString("iPod Disk Usage"));
+			SetTip(ipodEjectButton, Catalog.GetString("Eject iPod"));
+			SetTip(ipodSyncButton, Catalog.GetString("Synchronize Music Library to iPod"));
+			SetTip(ipodPropertiesButton, Catalog.GetString("View iPod Properties"));
 			
 			playlistMenuMap = new Hashtable();
 			
 			Core.Instance.DBusServer.RegisterObject(
-				new BansheeCore(Window), "/org/gnome/Banshee/Core");
+				new BansheeCore(Window, this), "/org/gnome/Banshee/Core");
       	}
       	
       	private void SetTip(Widget widget, string tip)
@@ -510,8 +522,8 @@ namespace Banshee
       		LabelInfo.Markup = "<span size=\"small\">" + text + "</span>";
       	}
       	
-      	private void TogglePlaying()
-		{		
+      	public void TogglePlaying()
+		{
 			if(Core.Instance.Player.Playing) {
 				ImagePlayPause.SetFromStock("media-play", 
 					IconSize.LargeToolbar);
@@ -638,18 +650,28 @@ namespace Banshee
 				playlistView.PlaySelected();
 		}
 		
-		private void OnButtonPreviousClicked(object o, EventArgs args)
+		public void Previous()
 		{
 			playlistModel.Regress();
 			playlistView.UpdateView();
 		}
 		
-		private void OnButtonNextClicked(object o, EventArgs args)
+		public void Next()
 		{
 			playlistModel.Advance();
 			playlistView.UpdateView();
 		}
 		
+		private void OnButtonPreviousClicked(object o, EventArgs args)
+		{
+			Previous();
+		}
+		
+		private void OnButtonNextClicked(object o, EventArgs args)
+		{
+			Next();
+		}
+		
 		private void OnVolumeScaleChanged(int volume)
 		{
 			Core.Instance.Player.Volume = (ushort)volume;
@@ -817,7 +839,7 @@ namespace Banshee
 				
 		private void OnMenuTrackPropertiesActivate(object o, EventArgs args)
 		{
-			new TrackProperties(playlistView.SelectedTrackInfo);
+			OnItemPropertiesActivate(o, args);
 		}
 		
 		private void OnMenuNewPlaylistActivate(object o, EventArgs args)
@@ -916,6 +938,18 @@ namespace Banshee
 			ShowSourceProperties(sourceView.SelectedSource);
 		}
 		
+		private void OnIpodSyncClicked(object o, EventArgs args)
+		{
+			if(sourceView.SelectedSource.Type != SourceType.Ipod)
+				return;
+		
+			IpodSource ipodSource = sourceView.SelectedSource as IpodSource;
+			IPod.Device device = ipodSource.Device;
+					
+			IpodSyncTransaction sync = new IpodSyncTransaction(device);
+			sync.Register();
+		}
+		
 		private void OnIpodEjectClicked(object o, EventArgs args)
 		{
 			EjectSource(sourceView.SelectedSource);
@@ -1034,7 +1068,7 @@ namespace Banshee
 			
 			foreach(TreePath path in playlistView.Selection.GetSelectedRows())			
 				playlistModel.GetIter(out iters[i++], path);
-				
+		
 			TrackRemoveTransaction transaction;
 			
 			if(playlistModel.Source.Type == SourceType.Library)
@@ -1054,7 +1088,14 @@ namespace Banshee
 		
 		private void OnItemPropertiesActivate(object o, EventArgs args)
 		{
-			new TrackProperties(playlistView.SelectedTrackInfo);
+			TrackProperties propEdit = new TrackProperties(
+				playlistView.SelectedTrackInfoMultiple);
+			propEdit.Saved += OnTrackPropertyEditorSaved;
+		}
+		
+		private void OnTrackPropertyEditorSaved(object o, EventArgs args)
+		{
+			playlistView.QueueDraw();
 		}
 		
 		private void OnButtonNewPlaylistClicked(object o, EventArgs args)
@@ -1331,15 +1372,33 @@ namespace Banshee
 		{
 			if((args.Event.State & ModifierType.Button1Mask) == 0)
 				return;
+			if(args.Event.Window != playlistView.BinWindow)
+				return;
 			if(!Gtk.Drag.CheckThreshold(playlistView, clickX, clickY,
 						    (int)args.Event.X, (int)args.Event.Y))
 				return;
 		
 			Gtk.Drag.Begin(playlistView, new TargetList (playlistViewSourceEntries),
-				       Gdk.DragAction.Move, 1, args.Event);
+				       Gdk.DragAction.Move | Gdk.DragAction.Copy, 1, args.Event);
 			args.RetVal = true;
 		}
 
+		private void OnPlaylistViewButtonReleaseEvent(object o, 
+			ButtonReleaseEventArgs args)
+		{
+			if(!Gtk.Drag.CheckThreshold(playlistView, clickX, clickY,
+						    (int)args.Event.X, (int)args.Event.Y) &&
+			   ((args.Event.State & (ModifierType.ControlMask 
+						 | ModifierType.ShiftMask)) == 0) &&
+			   playlistView.Selection.CountSelectedRows() > 1) {
+				TreePath path;
+				playlistView.GetPathAtPos((int)args.Event.X, 
+							  (int)args.Event.Y, out path);
+				playlistView.Selection.UnselectAll();
+				playlistView.Selection.SelectPath(path);
+			}
+		}
+
 		private bool PlaylistMenuPopupTimeout(uint time)
 		{
 			if(gxmlPlaylistMenu == null) {
